@@ -20,6 +20,13 @@
 # @author Martijn Schuemie
 # @author Marc Suchard
 
+#' SqlRender
+#'
+#' @docType package
+#' @name SqlRender
+#' @importFrom utils install.packages menu
+NULL
+
 .onLoad <- function(libname, pkgname) {
   rJava::.jpackage(pkgname, lib.loc = libname)
 }
@@ -86,7 +93,7 @@ renderSql <- function(sql = "", ...) {
 #' @param sql                The SQL to be translated
 #' @param sourceDialect      Deprecated: The source dialect. Currently, only "sql server" for Microsoft SQL Server
 #'                           is supported
-#' @param targetDialect      The target dialect. Currently "oracle", "postgresql", "pdw", "impala", "netezza", and
+#' @param targetDialect      The target dialect. Currently "oracle", "postgresql", "pdw", "impala", "netezza", "bigquery", and
 #'                           "redshift" are supported
 #' @param oracleTempSchema   A schema that can be used to create temp tables in when using Oracle or Impala.
 #' @return
